@@ -13,7 +13,7 @@ use English '-no_match_vars';
 use 5.006;
 
 # Declare package version
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # Patterns to match elements of the LRC file; these are somewhat tolerant
 our %RE = (
@@ -31,8 +31,8 @@ our %RE = (
         \s*         # Any whitespace
         \[          # Opening left bracket
             ([^:\r\n]+)  # Tag name, capture
-            :          # Colon
-            (.*)       # Tag value, capture
+            :            # Colon
+            (.*)         # Tag value, capture
         \]          # Closing right bracket
         \s*         # Any whitespace
         \z          # End of string
@@ -255,8 +255,8 @@ __END__
 =pod
 
 =for stopwords
-LRC tradename licensable MERCHANTABILITY arrayref hashrefs hashref millseconds
-filehandle writeable whitespace
+LRC tradename licensable MERCHANTABILITY arrayref hashrefs hashref filehandle
+writeable whitespace
 
 =head1 NAME
 
@@ -264,7 +264,7 @@ Music::Lyrics::LRC - Manipulate LRC karaoke timed lyrics files
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 DESCRIPTION
 
@@ -287,7 +287,8 @@ L<https://en.wikipedia.org/wiki/LRC_(file_format)>
     my $tags = $lrc->tags();  # hashref, name => value
     ...
     $lrc->add_lyric(5500, q(Now I'm singin' at exactly 5.5 seconds...));
-    $lrc->add_tag('author', 'Justin A. Perlhacker');
+    $lrc->set_tag('author', 'Justin A. Perlhacker');
+    $lrc->unset_tag('author');
     ...
     open my $wfh, '>', 'savelyrics.lrc';
     $lrc->save($wfh);
@@ -327,7 +328,7 @@ Retrieve a hashref of tag names to tag values for this lyrics file.
 
 =head2 C<add_lyric($time, $text)>
 
-Add a lyric at the given non-negative time in millseconds and with the given
+Add a lyric at the given non-negative time in milliseconds and with the given
 text. The text must not include newlines or carriage returns.
 
 =head2 C<set_tag($name, $value)>
